==> rustc-1.74_1.74.1+dfsg0ubuntu1.orig.tar.xz: rustc-1.74.1-src/tests/rustdoc-js-std/parser-ident.js <==
const PARSED = [
    {
        query: "R<!>",
        elems: [{
            name: "r",
            fullPath: ["r"],
            pathWithoutLast: [],
            pathLast: "r",
            generics: [
                {
                    name: "never",
                    fullPath: ["never"],
                    pathWithoutLast: [],
                    pathLast: "never",
                    generics: [],
                    typeFilter: 15,
                },
            ],
            typeFilter: -1,
        }],
        foundElems: 1,
        original: "R<!>",
        returned: [],
        userQuery: "r<!>",
        error: null,
    },
    {
        query: "!",
        elems: [{
            name: "never",
            fullPath: ["never"],
            pathWithoutLast: [],
            pathLast: "never",
            generics: [],
            typeFilter: 15,
        }],
        foundElems: 1,
        original: "!",
        returned: [],
        userQuery: "!",
        error: null,
    },
    {
        query: "a!",
        elems: [{
            name: "a",
            fullPath: ["a"],
            pathWithoutLast: [],
            pathLast: "a",
            generics: [],
            typeFilter: 14,
        }],
        foundElems: 1,
        original: "a!",
        returned: [],
        userQuery: "a!",
        error: null,
    },
    {
        query: "a!::b",
        elems: [],
        foundElems: 0,
        original: "a!::b",
        returned: [],
        userQuery: "a!::b",
        error: "Cannot have associated items in macros",
    },
    {
        query: "!<T>",
        elems: [],
        foundElems: 0,
        original: "!<T>",
        returned: [],
        userQuery: "!<t>",
        error: "Never type `!` does not accept generic parameters",
    },
    {
        query: "!::b",
        elems: [{
            name: "!::b",
            fullPath: ["never", "b"],
            pathWithoutLast: ["never"],
            pathLast: "b",
            generics: [],
            typeFilter: -1,
        }],
        foundElems: 1,
        original: "!::b",
        returned: [],
        userQuery: "!::b",
        error: null,
    },
    {
        query: "b::!",
        elems: [],
        foundElems: 0,
        original: "b::!",
        returned: [],
        userQuery: "b::!",
        error: "Never type `!` is not associated item",
    },
    {
        query: "!::!",
        elems: [],
        foundElems: 0,
        original: "!::!",
        returned: [],
        userQuery: "!::!",
        error: "Never type `!` is not associated item",
    },
    {
        query: "b::!::c",
        elems: [],
        foundElems: 0,
        original: "b::!::c",
        returned: [],
        userQuery: "b::!::c",
        error: "Never type `!` is not associated item",
    },
    {
        query: "!::b<T>",
        elems: [{
            name: "!::b",
            fullPath: ["never", "b"],
            pathWithoutLast: ["never"],
            pathLast: "b",
            generics: [
                {
                    name: "t",
                    fullPath: ["t"],
                    pathWithoutLast: [],
                    pathLast: "t",
                    generics: [],
                    typeFilter: -1,
                }
            ],
            typeFilter: -1,
        }],
        foundElems: 1,
        original: "!::b<T>",
        returned: [],
        userQuery: "!::b<t>",
        error: null,
    },
    {
        query: "a!::b!",
        elems: [],
        foundElems: 0,
        original: "a!::b!",
        returned: [],
        userQuery: "a!::b!",
        error: "Cannot have associated items in macros",
    },
];

==> rustc-1.88_1.88.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.88.0-src/tests/rustdoc-js-std/parser-ident.js <==
const PARSED = [
    {
        query: "R<!>",
        elems: [{
            name: "R",
            fullPath: ["r"],
            pathWithoutLast: [],
            pathLast: "r",
            generics: [
                {
                    name: "never",
                    fullPath: ["never"],
                    pathWithoutLast: [],
                    pathLast: "never",
                    generics: [],
                    typeFilter: 1,
                },
            ],
            typeFilter: -1,
        }],
        foundElems: 1,
        userQuery: "R<!>",
        returned: [],
        error: null,
    },
    {
        query: "!",
        elems: [{
            name: "never",
            fullPath: ["never"],
            pathWithoutLast: [],
            pathLast: "never",
            generics: [],
            typeFilter: 1,
        }],
        foundElems: 1,
        userQuery: "!",
        returned: [],
        error: null,
    },
    {
        query: "a!",
        elems: [{
            name: "a",
            fullPath: ["a"],
            pathWithoutLast: [],
            pathLast: "a",
            generics: [],
            typeFilter: 16,
        }],
        foundElems: 1,
        userQuery: "a!",
        returned: [],
        error: null,
    },
    {
        query: "a!::b",
        elems: [],
        foundElems: 0,
        userQuery: "a!::b",
        returned: [],
        error: "Cannot have associated items in macros",
    },
    {
        query: "!<T>",
        elems: [],
        foundElems: 0,
        userQuery: "!<T>",
        returned: [],
        error: "Never type `!` does not accept generic parameters",
    },
    {
        query: "!::b",
        elems: [{
            name: "!::b",
            fullPath: ["never", "b"],
            pathWithoutLast: ["never"],
            pathLast: "b",
            generics: [],
            typeFilter: -1,
        }],
        foundElems: 1,
        userQuery: "!::b",
        returned: [],
        error: null,
    },
    {
        query: "b::!",
        elems: [],
        foundElems: 0,
        userQuery: "b::!",
        returned: [],
        error: "Never type `!` is not associated item",
    },
    {
        query: "!::!",
        elems: [],
        foundElems: 0,
        userQuery: "!::!",
        returned: [],
        error: "Never type `!` is not associated item",
    },
    {
        query: "b::!::c",
        elems: [],
        foundElems: 0,
        userQuery: "b::!::c",
        returned: [],
        error: "Never type `!` is not associated item",
    },
    {
        query: "!::b<T>",
        elems: [{
            name: "!::b",
            fullPath: ["never", "b"],
            pathWithoutLast: ["never"],
            pathLast: "b",
            generics: [
                {
                    name: "T",
                    fullPath: ["t"],
                    pathWithoutLast: [],
                    pathLast: "t",
                    generics: [],
                    typeFilter: -1,
                }
            ],
            typeFilter: -1,
        }],
        foundElems: 1,
        userQuery: "!::b<T>",
        returned: [],
        error: null,
    },
    {
        query: "a!::b!",
        elems: [],
        foundElems: 0,
        userQuery: "a!::b!",
        returned: [],
        error: "Cannot have associated items in macros",
    },
];
